@@ -2,7 +2,7 @@ from bolinette.web.method import HttpMethod
 from bolinette.web.controller import (
     Controller, ControllerMetadata, ControllerRoute, Expects, Returns, MiddlewareTrack
 )
-from bolinette.web.middleware import Middleware, MiddlewareMetadata
+from bolinette.web.middleware import Middleware, MiddlewareMetadata, InternalMiddleware
 from bolinette.web.topic import Topic, TopicMetadata, TopicChannel
 from bolinette.web.resources import BolinetteResources, BolinetteResource
 from bolinette.web.sockets import BolinetteSockets
